@@ -2,8 +2,7 @@ from bluesky_live.run_builder import build_simple_run
 import pytest
 
 from ..plot_builders import Lines
-from ..plot_specs import AxesSpec, FigureSpec
-from ...headless.figures import HeadlessFigure
+from ..plot_specs import Axes, Figure
 
 
 # Make some runs to use.
@@ -17,12 +16,12 @@ runs = [
 MAX_RUNS = 3
 
 
-def test_pinned():
+def test_pinned(FigureView):
     "Test Lines with 'pinned' and un-pinned runs."
     ys = ["det", "det2"]
     num_ys = len(ys)
     model = Lines("motor", ys, max_runs=MAX_RUNS)
-    view = HeadlessFigure(model.figure)
+    view = FigureView(model.figure)
 
     # Add MAX_RUNS and then some more and check that they do get bumped off.
     for run in runs[:5]:
@@ -37,23 +36,23 @@ def test_pinned():
     for run in runs[6:]:
         model.add_run(run)
         assert len(model.runs) == 1 + MAX_RUNS
-        assert len(model.figure.axes[0].lines) == num_ys * (1 + MAX_RUNS)
+        assert len(model.figure.axes[0].artists) == num_ys * (1 + MAX_RUNS)
     # Check that it hasn't been bumped off.
     assert pinned_run in model.runs
 
     # Remove the pinned run.
     model.discard_run(pinned_run)
     assert len(model.runs) == MAX_RUNS
-    assert len(model.figure.axes[0].lines) == num_ys * MAX_RUNS
+    assert len(model.figure.axes[0].artists) == num_ys * MAX_RUNS
     assert pinned_run not in model.runs
 
     view.close()
 
 
-def test_properties():
+def test_properties(FigureView):
     "Touch various accessors"
     model = Lines("c * motor", ["det"], namespace={"c": 3}, max_runs=MAX_RUNS)
-    view = HeadlessFigure(model.figure)
+    view = FigureView(model.figure)
     model.add_run(runs[0])
     assert model.runs[0] is runs[0]
     assert model.max_runs == MAX_RUNS
@@ -66,31 +65,31 @@ def test_properties():
     view.close()
 
 
-def test_decrease_max_runs():
+def test_decrease_max_runs(FigureView):
     "Decreasing max_runs should remove the runs and their associated lines."
     INITIAL_MAX_RUNS = 5
     model = Lines("motor", ["det"], namespace={"c": 3}, max_runs=INITIAL_MAX_RUNS)
-    view = HeadlessFigure(model.figure)
+    view = FigureView(model.figure)
     for run in runs[:5]:
         model.add_run(run)
     assert len(model.runs) == INITIAL_MAX_RUNS
-    assert len(model.figure.axes[0].lines) == INITIAL_MAX_RUNS
+    assert len(model.figure.axes[0].artists) == INITIAL_MAX_RUNS
     # Decrease max_runs.
     model.max_runs = MAX_RUNS
     assert len(model.runs) == MAX_RUNS
-    assert len(model.figure.axes[0].lines) == MAX_RUNS
+    assert len(model.figure.axes[0].artists) == MAX_RUNS
 
     view.close()
 
 
 @pytest.mark.parametrize("expr", ["det / det2", "-log(det)", "np.sqrt(det)"])
-def test_expressions(expr):
+def test_expressions(expr, FigureView):
     "Test Lines with 'pinned' and un-pinned runs."
     ys = [expr]
     model = Lines("motor", ys, max_runs=MAX_RUNS)
-    view = HeadlessFigure(model.figure)
+    view = FigureView(model.figure)
     model.add_run(runs[0])
-    assert len(model.figure.axes[0].lines) == 1
+    assert len(model.figure.axes[0].artists) == 1
 
     view.close()
 
@@ -102,23 +101,24 @@ def test_expressions(expr):
         lambda det, log: -log(det),
         lambda det, np: np.sqrt(det),
     ],
+    ids=["division", "top-level-log", "np-dot-log"],
 )
-def test_functions(func):
+def test_functions(func, FigureView):
     "Test Lines with 'pinned' and un-pinned runs."
     ys = [func]
     model = Lines("motor", ys, max_runs=MAX_RUNS)
-    view = HeadlessFigure(model.figure)
+    view = FigureView(model.figure)
     model.add_run(runs[0])
-    assert len(model.figure.axes[0].lines) == 1
+    assert len(model.figure.axes[0].artists) == 1
 
     view.close()
 
 
-def test_figure_set_after_instantiation():
-    axes = AxesSpec()
+def test_figure_set_after_instantiation(FigureView):
+    axes = Axes()
     model = Lines("motor", [], axes=axes)
     assert model.figure is None
-    figure = FigureSpec((axes,), title="")
+    figure = Figure((axes,), title="")
     assert model.figure is figure
-    view = HeadlessFigure(model.figure)
+    view = FigureView(model.figure)
     view.close()
