@@ -4,10 +4,10 @@ import itertools
 import numpy
 
 from .plot_specs import (
-    FigureSpec,
-    AxesSpec,
-    ImageSpec,
-    LineSpec,
+    Figure,
+    Axes,
+    Image,
+    Line,
 )
 from .utils import auto_label, call_or_eval, RunManager, run_is_live_and_not_completed
 from ..utils.dict_view import DictView
@@ -59,7 +59,7 @@ class Lines:
         Streams referred to by x and y. Default is ``["primary"]``
     namespace : Dict, optional
         Inject additional tokens to be used in expressions for x and y
-    axes : AxesSpec, optional
+    axes : Axes, optional
         If None, an axes and figure are created with default labels and titles
         derived from the ``x`` and ``y`` parameters.
 
@@ -75,8 +75,8 @@ class Lines:
         last (first in, first out) so that there are at most ``max_runs``.
     pinned : Frozenset[String]
         Run uids of pinned runs.
-    figure : FigureSpec
-    axes : AxesSpec
+    figure : Figure
+    axes : Axes
     x : String | Callable
         Read-only access to x
     ys : Tuple[String | Callable]
@@ -177,11 +177,11 @@ class Lines:
         self._label_maker = label_maker
         self._namespace = namespace
         if axes is None:
-            axes = AxesSpec(
+            axes = Axes(
                 x_label=auto_label(self.x),
                 y_label=", ".join(auto_label(y) for y in self.ys),
             )
-            figure = FigureSpec((axes,), title=f"{axes.y_label} v {axes.x_label}")
+            figure = Figure((axes,), title=f"{axes.y_label} v {axes.x_label}")
         else:
             figure = axes.figure
         self.axes = axes
@@ -204,7 +204,7 @@ class Lines:
         self.discard_run = self._run_manager.discard_run
 
     def _transform(self, run, x, y):
-        return call_or_eval((x, y), run, self.needs_streams, self.namespace)
+        return call_or_eval({"x": x, "y": y}, run, self.needs_streams, self.namespace)
 
     def _add_lines(self, event):
         "Add a line."
@@ -230,9 +230,9 @@ class Lines:
                 label += " (pinned)"
 
             func = functools.partial(self._transform, x=self.x, y=y)
-            line = LineSpec(func, run, label, style)
-            self._run_manager.track_artist(line)
-            self.axes.lines.append(line)
+            line = Line.from_run(func, run, label, style)
+            self._run_manager.track_artist(line, [run])
+            self.axes.artists.append(line)
 
     @property
     def x(self):
@@ -292,7 +292,7 @@ class Images:
         Streams referred to by field. Default is ``["primary"]``
     namespace : Dict, optional
         Inject additional tokens to be used in expressions for x and y
-    axes : AxesSpec, optional
+    axes : Axes, optional
         If None, an axes and figure are created with default labels and titles
         derived from the ``x`` and ``y`` parameters.
 
@@ -308,8 +308,8 @@ class Images:
         last (first in, first out) so that there are at most ``max_runs``.
     pinned : Frozenset[String]
         Run uids of pinned runs.
-    figure : FigureSpec
-    axes : AxesSpec
+    figure : Figure
+    axes : Axes
     field : String
         Read-only access to field or expression
     needs_streams : List[String], optional
@@ -354,8 +354,8 @@ class Images:
         self._label_maker = label_maker
         self._namespace = namespace
         if axes is None:
-            axes = AxesSpec()
-            figure = FigureSpec((axes,), title="")
+            axes = Axes()
+            figure = Figure((axes,), title="")
         else:
             figure = axes.figure
         self.axes = axes
@@ -378,32 +378,22 @@ class Images:
     def _add_images(self, event):
         run = event.run
         func = functools.partial(self._transform, field=self.field)
-        image = ImageSpec(func, run, label=self.field)
-        array_shape = run.primary.read()[self.field].shape
-        self._run_manager.track_artist(image)
-        self.axes.images.append(image)
+        image = Image.from_run(func, run, label=self.field)
+        self._run_manager.track_artist(image, [run])
+        self.axes.artists.append(image)
         self.axes.title = self._label_maker(run, self.field)
-        # By default, pixels center on integer coordinates ranging from 0 to
-        # columns-1 horizontally and 0 to rows-1 vertically.
-        # In order to see entire pixels, we set lower limits to -0.5
-        # and upper limits to columns-0.5 horizontally and rows-0.5 vertically
-        # if limits aren't specifically set.
-        if self.axes.x_limits is None:
-            self.axes.x_limits = (-0.5, array_shape[-1] - 0.5)
-        if self.axes.y_limits is None:
-            self.axes.y_limits = (-0.5, array_shape[-2] - 0.5)
         # TODO Set axes x, y from xarray dims
 
     def _transform(self, run, field):
-        (data,) = numpy.asarray(
-            call_or_eval((field,), run, self.needs_streams, self.namespace)
-        )
+        result = call_or_eval({"array": field}, run, self.needs_streams, self.namespace)
         # If the data is more than 2D, take the middle slice from the leading
         # axis until there are only two axes.
+        data = result["array"]
         while data.ndim > 2:
             middle = data.shape[0] // 2
             data = data[middle]
-        return data
+        result["array"] = data
+        return result
 
     @property
     def field(self):
@@ -456,7 +446,7 @@ class RasteredImages:
         Streams referred to by field. Default is ``["primary"]``
     namespace : Dict, optional
         Inject additional tokens to be used in expressions for x and y
-    axes : AxesSpec, optional
+    axes : Axes, optional
         If None, an axes and figure are created with default labels and titles
         derived from the ``x`` and ``y`` parameters.
     clim : Tuple, optional
@@ -476,8 +466,8 @@ class RasteredImages:
     ----------
     run : BlueskyRun
         The currently-viewed Run
-    figure : FigureSpec
-    axes : AxesSpec
+    figure : Figure
+    axes : Axes
     field : String
         Read-only access to field or expression
     needs_streams : List[String], optional
@@ -531,8 +521,8 @@ class RasteredImages:
         self._run = None
 
         if axes is None:
-            axes = AxesSpec()
-            figure = FigureSpec((axes,), title="")
+            axes = Axes()
+            figure = Figure((axes,), title="")
         else:
             figure = axes.figure
         self.axes = axes
@@ -564,8 +554,9 @@ class RasteredImages:
     @cmap.setter
     def cmap(self, value):
         self._cmap = value
-        for image in self.axes.images:
-            image.style.update({"cmap": value})
+        for artist in self.axes.artists:
+            if isinstance(artist, Image):
+                artist.style.update({"cmap": value})
 
     @property
     def clim(self):
@@ -574,8 +565,9 @@ class RasteredImages:
     @clim.setter
     def clim(self, value):
         self._clim = value
-        for image in self.axes.images:
-            image.style.update({"clim": value})
+        for artist in self.axes.artists:
+            if isinstance(artist, Image):
+                artist.style.update({"clim": value})
 
     @property
     def extent(self):
@@ -584,8 +576,9 @@ class RasteredImages:
     @extent.setter
     def extent(self, value):
         self._extent = value
-        for image in self.axes.images:
-            image.style.update({"extent": value})
+        for artist in self.axes.artist:
+            if isinstance(artist, Image):
+                artist.style.update({"extent": value})
 
     @property
     def x_positive(self):
@@ -641,10 +634,10 @@ class RasteredImages:
         run = event.run
         func = functools.partial(self._transform, field=self.field)
         style = {"cmap": self._cmap, "clim": self._clim, "extent": self._extent}
-        image = ImageSpec(func, run, label=self.field, style=style)
-        self._run_manager.track_artist(image)
+        image = Image.from_run(func, run, label=self.field, style=style)
+        self._run_manager.track_artist(image, [run])
         md = run.metadata["start"]
-        self.axes.images.append(image)
+        self.axes.artists.append(image)
         self.axes.title = self._label_maker(run, self.field)
         self.axes.x_label = md["motors"][1]
         self.axes.y_label = md["motors"][0]
@@ -666,9 +659,8 @@ class RasteredImages:
 
     def _transform(self, run, field):
         image_data = numpy.ones(self._shape) * numpy.nan
-        (data,) = numpy.asarray(
-            call_or_eval((field,), run, self.needs_streams, self.namespace)
-        )
+        result = call_or_eval({"data": field}, run, self.needs_streams, self.namespace)
+        data = result["data"]
         snaking = run.metadata["start"]["snaking"]
         for index in range(len(data)):
             pos = list(numpy.unravel_index(index, self._shape))
@@ -676,8 +668,7 @@ class RasteredImages:
                 pos[1] = self._shape[1] - pos[1] - 1
             pos = tuple(pos)
             image_data[pos] = data[index]
-
-        return image_data
+        return {"array": image_data}
 
     @property
     def namespace(self):
